Enum ts3plugin_sys::public_definitions::ClientCommand
[−]
[src]
#[repr(C)]pub enum ClientCommand { RequestConnectionInfo, RequestClientMove, RequestXXMuteClients, RequestClientKickFromXXX, FlushChannelCreation, FlushChannelUpdate, RequestChannelMove, RequestChannelDelete, RequestChannelDescription, RequestChannelXXSubscripeXX, RequestServerConnectionInfo, RequestSendXXXTextMsg, FileTransfer, Endmarker, }
This enum is used to disable client commands on the server
Variants
RequestConnectionInfoRequestClientMoveRequestXXMuteClientsRequestClientKickFromXXXFlushChannelCreationFlushChannelUpdateRequestChannelMoveRequestChannelDeleteRequestChannelDescriptionRequestChannelXXSubscripeXXRequestServerConnectionInfoRequestSendXXXTextMsgFileTransferEndmarkerTrait Implementations
impl Debug for ClientCommand[src]
impl PartialEq for ClientCommand[src]
fn eq(&self, __arg_0: &ClientCommand) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for ClientCommand[src]
impl Clone for ClientCommand[src]
fn clone(&self) -> ClientCommand
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more