Enum ts3plugin_sys::public_definitions::CodecType [] [src]

#[repr(C)]
pub enum CodecType { SpeexNarrowband, SpeexWideband, SpeexUltrawideband, CeltMono, OpusVoice, OpusMusic, }

Variants

Mono, 16bit, 8kHz, bitrate dependent on the quality setting

Mono, 16bit, 16kHz, bitrate dependent on the quality setting

Mono, 16bit, 32kHz, bitrate dependent on the quality setting

Mono, 16bit, 48kHz, bitrate dependent on the quality setting

Mono, 16bit, 48kHz, bitrate dependent on the quality setting, optimized for voice

Stereo, 16bit, 48kHz, bitrate dependent on the quality setting, optimized for music