ConnectionProperties

Enum ConnectionProperties 

#[repr(C)]
pub enum ConnectionProperties {
Show 67 variants Ping = 0, PingDeviation = 1, ConnectedTime = 2, IdleTime = 3, ClientIp = 4, ClientPort = 5, ServerIp = 6, ServerPort = 7, PacketsSentSpeech = 8, PacketsSentKeepalive = 9, PacketsSentControl = 10, PacketsSentTotal = 11, BytesSentSpeech = 12, BytesSentKeepalive = 13, BytesSentControl = 14, BytesSentTotal = 15, PacketsReceivedSpeech = 16, PacketsReceivedKeepalive = 17, PacketsReceivedControl = 18, PacketsReceivedTotal = 19, BytesReceivedSpeech = 20, BytesReceivedKeepalive = 21, BytesReceivedControl = 22, BytesReceivedTotal = 23, PacketlossSpeech = 24, PacketlossKeepalive = 25, PacketlossControl = 26, PacketlossTotal = 27, Server2ClientPacketlossSpeech = 28, Server2ClientPacketlossKeepalive = 29, Server2ClientPacketlossControl = 30, Server2ClientPacketlossTotal = 31, Client2ServerPacketlossSpeech = 32, Client2ServerPacketlossKeepalive = 33, Client2ServerPacketlossControl = 34, Client2ServerPacketlossTotal = 35, BandwidthSentLastSecondSpeech = 36, BandwidthSentLastSecondKeepalive = 37, BandwidthSentLastSecondControl = 38, BandwidthSentLastSecondTotal = 39, BandwidthSentLastMinuteSpeech = 40, BandwidthSentLastMinuteKeepalive = 41, BandwidthSentLastMinuteControl = 42, BandwidthSentLastMinuteTotal = 43, BandwidthReceivedLastSecondSpeech = 44, BandwidthReceivedLastSecondKeepalive = 45, BandwidthReceivedLastSecondControl = 46, BandwidthReceivedLastSecondTotal = 47, BandwidthReceivedLastMinuteSpeech = 48, BandwidthReceivedLastMinuteKeepalive = 49, BandwidthReceivedLastMinuteControl = 50, BandwidthReceivedLastMinuteTotal = 51, Dummy0 = 52, Dummy1 = 53, Dummy2 = 54, Dummy3 = 55, Dummy4 = 56, Dummy5 = 57, Dummy6 = 58, Dummy7 = 59, Dummy8 = 60, Dummy9 = 61, FileTransferBandwidthSent = 62, FiletransferBandwidthReceived = 63, FiletransferBytesReceivedTotal = 64, FiletransferBytesSentTotal = 65, Endmarker = 66,
}

Variants



Ping = 0

UInt64. Round trip latency for the connection based on the last 5 seconds. On the server this is the average across all connected clients for the last 5 seconds.



PingDeviation = 1

Double. Standard deviation for the round trip latency in CONNECTION_PING



ConnectedTime = 2

UInt64. Seconds the client has been connected.



IdleTime = 3

UInt64. Time in seconds since the last activity (voice transmission, switching channels, changing mic / speaker mute status) of the client.



ClientIp = 4

String. IP of this client (as seen from the server side)



ClientPort = 5

UInt64. Client side port of this client (as seen from the server side)



ServerIp = 6

String. The IP or hostname used to connect to the server. Only available on yourself.



ServerPort = 7

UInt64. The server port connected to. Only available on yourself.



PacketsSentSpeech = 8

UInt64. The number of voice packets transmitted by the client.



PacketsSentKeepalive = 9

UInt64. The number of keep alive packets transmitted by the client.



PacketsSentControl = 10

UInt64. The number of command & control packets transmitted by the client.



PacketsSentTotal = 11

UInt64. Total number of packets transmitted by the client. Equal to the sum of CONNECTION_PACKETS_SENT_SPEECH, CONNECTION_PACKETS_SENT_KEEPALIVE and CONNECTION_PACKETS_SENT_CONTROL



BytesSentSpeech = 12

UInt64. Outgoing traffic used for voice data by the client.



BytesSentKeepalive = 13

UInt64. Outgoing traffic used for keeping the connection alive by the client.



BytesSentControl = 14

UInt64. Outgoing traffic used for command & control data by the client.



BytesSentTotal = 15

UInt64. Total outgoing traffic to the server by this client. Equal to the sum of CONNECTION_BYTES_SENT_SPEECH, CONNECTION_BYTES_SENT_KEEPALIVE and CONNECTION_BYTES_SENT_CONTROL



PacketsReceivedSpeech = 16

UInt64. Number of voice packets received by the client.



PacketsReceivedKeepalive = 17

UInt64. Number of keep alive packets received by the client.



PacketsReceivedControl = 18

UInt64. Number of command & control packets received by the client.



PacketsReceivedTotal = 19

UInt64. Total number of packets received by the client. Equal to the sum of CONNECTION_PACKETS_RECEIVED_SPEECH, CONNECTION_PACKETS_RECEIVED_KEEPALIVE and CONNECTION_PACKETS_RECEIVED_CONTROL



BytesReceivedSpeech = 20

UInt64. Incoming traffic used by the client for voice data.



BytesReceivedKeepalive = 21

UInt64. Incoming traffic used by the client to keep the connection alive.



BytesReceivedControl = 22

UInt64. Incoming traffic used by the client for command & control data.



BytesReceivedTotal = 23

UInt64. Total incoming traffic used by the client. Equal to the sum of CONNECTION_BYTES_RECEIVED_SPEECH, CONNECTION_BYTES_RECEIVED_KEEPALIVE and CONNECTION_BYTES_RECEIVED_CONTROL



PacketlossSpeech = 24

Double. Percentage points of voice packets for the client that did not arrive at the client or server averaged across the last 5 seconds.



PacketlossKeepalive = 25

Double. Percentage points of keep alive packets for the client that did not arrive at the client or server averaged across the last 5 seconds.



PacketlossControl = 26

Double. Percentage points of command & control packets for the client that did not arrive at the client or server averaged across the last 5 seconds.



PacketlossTotal = 27

Double. Cumulative chance in percentage points with which a packet round trip failed because a packet was lost



Server2ClientPacketlossSpeech = 28

Double. Probability with which a voice packet sent by the server was not received by the client.



Server2ClientPacketlossKeepalive = 29

Double. Probability with which a keepalive packet sent by the server was not received by the client.



Server2ClientPacketlossControl = 30

Double. Probability with which a control packet sent by the server was not received by the client.



Server2ClientPacketlossTotal = 31

Double. Probability with which a packet sent by the server was not received by the client.



Client2ServerPacketlossSpeech = 32

Double. Probability with which a speech packet sent by the client was not received by the server.



Client2ServerPacketlossKeepalive = 33

Double. Probability with which a keepalive packet sent by the client was not received by the server.



Client2ServerPacketlossControl = 34

Double. Probability with which a control packet sent by the client was not received by the server.



Client2ServerPacketlossTotal = 35

Double. Probability with which a packet sent by the client was not received by the server.



BandwidthSentLastSecondSpeech = 36

UInt64. Number of bytes sent for speech data in the last second.



BandwidthSentLastSecondKeepalive = 37

UInt64. Number of bytes sent for keepalive data in the last second.



BandwidthSentLastSecondControl = 38

UInt64. Number of bytes sent for control data in the last second.



BandwidthSentLastSecondTotal = 39

UInt64. Number of bytes sent in the last second.



BandwidthSentLastMinuteSpeech = 40

UInt64. Bytes per second sent for speech data, averaged over the last minute.



BandwidthSentLastMinuteKeepalive = 41

UInt64. Bytes per second sent for keepalive data, averaged over the last minute.



BandwidthSentLastMinuteControl = 42

UInt64. Bytes per second sent for control data, averaged over the last minute.



BandwidthSentLastMinuteTotal = 43

UInt64. Bytes per second sent, averaged over the last minute.



BandwidthReceivedLastSecondSpeech = 44

UInt64. Number of bytes received for speech data in the last second.



BandwidthReceivedLastSecondKeepalive = 45

UInt64. Number of bytes received for keepalive data in the last second.



BandwidthReceivedLastSecondControl = 46

UInt64. Number of bytes received for control data in the last second.



BandwidthReceivedLastSecondTotal = 47

UInt64. Number of bytes received in the last second.



BandwidthReceivedLastMinuteSpeech = 48

UInt64. Bytes per second received for speech data, averaged over the last minute.



BandwidthReceivedLastMinuteKeepalive = 49

UInt64. Bytes per second received for keepalive data, averaged over the last minute.



BandwidthReceivedLastMinuteControl = 50

UInt64. Bytes per second received for control data, averaged over the last minute.



BandwidthReceivedLastMinuteTotal = 51

UInt64. Bytes per second received, averaged over the last minute.



Dummy0 = 52

Rare properties



Dummy1 = 53



Dummy2 = 54



Dummy3 = 55



Dummy4 = 56



Dummy5 = 57



Dummy6 = 58



Dummy7 = 59



Dummy8 = 60



Dummy9 = 61



FileTransferBandwidthSent = 62

UInt64. Current file transfer upstream activity in bytes per second. Only available on request (ts3client_requestServerConnectionInfo).



FiletransferBandwidthReceived = 63

UInt64. Current file transfer downstream activity in bytes per second. Only available on request ( ts3client_requestServerConnectionInfo).



FiletransferBytesReceivedTotal = 64

UInt64. Total downstream traffic, in bytes, used for file transfer since the server was started. Only available on request (\ref ts3client_requestServerConnectionInfo).



FiletransferBytesSentTotal = 65

UInt64. Total upstream traffic, in bytes, used for file transfer since the server was started. Only available on request ( ts3client_requestServerConnectionInfo).



Endmarker = 66