Enum ts3plugin_sys::public_definitions::GroupWhisperTargetMode
[−]
[src]
#[repr(C)]pub enum GroupWhisperTargetMode { All, Currentchannel, Parentchannel, Allparentchannel, Channelfamily, Ancestorchannelfamily, Subchannels, Endmarker, }
Variants
AllCurrentchannelParentchannelAllparentchannelChannelfamilyAncestorchannelfamilySubchannelsEndmarkerTrait Implementations
impl Debug for GroupWhisperTargetMode[src]
impl PartialEq for GroupWhisperTargetMode[src]
fn eq(&self, __arg_0: &GroupWhisperTargetMode) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for GroupWhisperTargetMode[src]
impl Clone for GroupWhisperTargetMode[src]
fn clone(&self) -> GroupWhisperTargetMode
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more