Enum ts3plugin_sys::public_definitions::PluginTargetMode
[−]
[src]
#[repr(C)]pub enum PluginTargetMode { CurrentChannel, Server, Client, CurrentChannelSubscribedClients, Max, }
Variants
CurrentChannelSend plugincmd to all clients in current channel
ServerSend plugincmd to all clients on server
ClientSend plugincmd to all given client ids
CurrentChannelSubscribedClientsSend plugincmd to all subscribed clients in current channel
MaxTrait Implementations
impl Debug for PluginTargetMode[src]
impl PartialEq for PluginTargetMode[src]
fn eq(&self, __arg_0: &PluginTargetMode) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for PluginTargetMode[src]
impl Clone for PluginTargetMode[src]
fn clone(&self) -> PluginTargetMode
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more