ServerInstancePropertiesRare

Enum ServerInstancePropertiesRare 

#[repr(C)]
pub enum ServerInstancePropertiesRare {
Show 19 variants DatabaseVersion = 0, FiletransferPort = 1, ServerEntropy = 2, MonthlyTimestamp = 3, MaxDownloadTotalBandwidth = 4, MaxUploadTotalBandwidth = 5, GuestServerqueryGroup = 6, ServerqueryFloodCommands = 7, ServerqueryFloodTime = 8, ServerqueryBanTime = 9, TemplateServeradminGroup = 10, TemplateServerdefaultGroup = 11, TemplateChanneladminGroup = 12, TemplateChannelDefaultGroup = 13, PermissionsVersion = 14, PendingConnectionsPerIp = 15, ServerqueryMaxConnectionsPerIp = 16, MaxHomebases = 17, Endmarker = 18,
}

Variants



DatabaseVersion = 0



FiletransferPort = 1



ServerEntropy = 2



MonthlyTimestamp = 3



MaxDownloadTotalBandwidth = 4



MaxUploadTotalBandwidth = 5



GuestServerqueryGroup = 6



ServerqueryFloodCommands = 7

How many commands we can issue while in the SERVERINSTANCE_SERVERQUERY_FLOOD_TIME window



ServerqueryFloodTime = 8

Time window in seconds for max command execution check



ServerqueryBanTime = 9

How many seconds someone get banned if he floods



TemplateServeradminGroup = 10



TemplateServerdefaultGroup = 11



TemplateChanneladminGroup = 12



TemplateChannelDefaultGroup = 13



PermissionsVersion = 14



PendingConnectionsPerIp = 15



ServerqueryMaxConnectionsPerIp = 16



MaxHomebases = 17

How many matrix homebase users this instance can have. -1 for no limit



Endmarker = 18