#[repr(C)]pub enum TextMessageTargetMode {
Client = 1,
Channel = 2,
Server = 3,
Max = 4,
}Variants
Client = 1
Message is a private message to another client
Channel = 2
Message is sent to a channel, received by all clients in that channel at the time
Server = 3
Message is sent to every client on the server
Max = 4