VirtualServerProperties

Enum VirtualServerProperties 

#[repr(C)]
pub enum VirtualServerProperties {
Show 98 variants UniqueIdentifier = 0, Name = 1, Welcomemessage = 2, Platform = 3, Version = 4, MaxClients = 5, Password = 6, ClientsOnline = 7, ChannelsOnline = 8, Created = 9, Uptime = 10, CodecEncryptionMode = 11, EncryptionCiphers = 12, Dummy1 = 13, Dummy2 = 14, Dummy3 = 15, Dummy4 = 16, Dummy5 = 17, Dummy6 = 18, Dummy7 = 19, Dummy8 = 20, Keypair = 21, Hostmessage = 22, HostmessageMode = 23, Filebase = 24, DefaultServerGroup = 25, DefaultChannelGroup = 26, FlagPassword = 27, DefaultChannelAdminGroup = 28, MaxDownloadTotalBandwidth = 29, MaxUploadTotalBandwidth = 30, HostbannerUrl = 31, HostbannerGfxUrl = 32, HostbannerGfxInterval = 33, ComplainAutobanCount = 34, ComplainAutobanTime = 35, ComplainRemoveTime = 36, MinClientsInChannelBeforeForcedSilence = 37, PrioritySpeakerDimmModificator = 38, Id = 39, AntifloodPointsTickReduce = 40, AntifloodPointsNeededCommandBlock = 41, AntifloodPointsNeededIpBlock = 42, ClientConnections = 43, QueryClientConnections = 44, HostbuttonTooltip = 45, HostbuttonUrl = 46, HostbuttonGfxUrl = 47, QueryclientsOnline = 48, DownloadQuota = 49, UploadQuota = 50, MonthBytesDownloaded = 51, MonthBytesUploaded = 52, TotalBytesDownloaded = 53, TotalBytesUploaded = 54, Port = 55, Autostart = 56, MachineId = 57, NeededIdentitySecurityLevel = 58, LogClient = 59, LogQuery = 60, LogChannel = 61, LogPermissions = 62, LogServer = 63, LogFiletransfer = 64, MinClientVersion = 65, NamePhonetic = 66, IconId = 67, ReservedSlots = 68, TotalPacketlossSpeech = 69, TotalPacketlossKeepalive = 70, TotalPacketlossControl = 71, TotalPacketlossTotal = 72, TotalPing = 73, Ip = 74, WeblistEnabled = 75, AutogeneratedPrivilegekey = 76, AskForPrivilegekey = 77, HostbannerMode = 78, ChannelTempDeleteDelayDefault = 79, MinAndroidVersion = 80, MinIosVersion = 81, MinWinphoneVersion = 82, Nickname = 83, AccountingToken = 84, ProtocolVerifyKeypair = 85, AntifloodPointsNeededPluginBlock = 86, CapabilityExtensions = 87, StorageQuota = 88, WebrtcCertificate = 89, WebrtcPrivateKey = 90, Uuid = 91, AdministrativeDomain = 92, CanonicalName = 93, MytsidConnectOnly = 94, MaxHomebases = 95, HomebaseStorageQuota = 96, Endmarker = 97,
}

Variants



UniqueIdentifier = 0

String. Read only. Unique identifier for a virtual server, does not change on server restart. Available if ts3client_getConnectionStatus is >= STATUS_CONNECTED.



Name = 1

String. Read/Write. The virtual server display name. Available if ts3client_getConnectionStatus is >= STATUS_CONNECTED.



Welcomemessage = 2

String. Read/Write. The welcome message displayed to clients on connect. Available if ts3client_getConnectionStatus is >= STATUS_CONNECTED. Not updated automatically when changed, updates need to be requested ( ts3client_requestServerVariables).



Platform = 3

String. Read only. The operating system the server is running on. Available if ts3client_getConnectionStatus is >= STATUS_CONNECTED.



Version = 4

String. Read only. The server software version string. Available if ts3client_getConnectionStatus is >= STATUS_CONNECTED.



MaxClients = 5

UInt64. Read/Write. The maximum number of clients that can be connected simultaneously. Only available on request (ts3client_requestServerVariables).



Password = 6

String. Read/Write. The server password. Read access is limited to the server. Clients will only get the password they supplied when connecting. Available if ts3client_getConnectionStatus is >= STATUS_CONNECTED.



ClientsOnline = 7

UInt64. Read only. The current number of clients connected to the server, including query connections. Only available on request (\ref ts3client_requestServerVariables).



ChannelsOnline = 8

UInt64. Read only. The current number of channels on the server. Only available on request (ts3client_requestServerVariables).



Created = 9

Integer. Read only. The time this virtual server was created as unix timestamp. Available if ts3client_getConnectionStatus is >= STATUS_CONNECTED.



Uptime = 10

UInt64. Read only. Number of seconds that have passed since the virtual server was started. Only available on request (ts3client_requestServerVariables).



CodecEncryptionMode = 11

Integer. Read/Write. Boolean (1/0) that specifies if voice data is encrypted during transfer. One of the values from the CodecEncryptionMode enum. Available if ts3client_getConnectionStatus is >= STATUS_CONNECTED.



EncryptionCiphers = 12

String. Read/Write. Comma separated list of available ciphers to encrypt the connection. The server will use the first cipher in the list that is also listed in the CLIENT_ENCRYPTION_CIPHERS of the connecting client. Clients will fail to connect if no match is found. Always available.



Dummy1 = 13

Rare properties



Dummy2 = 14



Dummy3 = 15



Dummy4 = 16



Dummy5 = 17



Dummy6 = 18



Dummy7 = 19



Dummy8 = 20



Keypair = 21

Internal use



Hostmessage = 22

Available when connected, not updated while connected



HostmessageMode = 23

Available when connected, not updated while connected



Filebase = 24

String. Read only. The path to the base directory used to store files transferred using file transfer. Available only on the server. Is set by ts3server_enableFileManager



DefaultServerGroup = 25

The client permissions server group that a new client gets assigned



DefaultChannelGroup = 26

The channel permissions group that a new client gets assigned when joining a channel



FlagPassword = 27

Only available on request (=> requestServerVariables)



DefaultChannelAdminGroup = 28

The channel permissions group that a client gets assigned when creating a channel



MaxDownloadTotalBandwidth = 29

UInt64. Read/Write. Maximum traffic in bytes the server can use for file transfer downloads. Only available on request (ts3client_requestServerVariables).



MaxUploadTotalBandwidth = 30

UInt64. Read/Write. Maximum traffic in bytes the server can use for file transfer uploads. Only available on request (ts3client_requestServerVariables).



HostbannerUrl = 31

Available when connected, always up-to-date



HostbannerGfxUrl = 32

Available when connected, always up-to-date



HostbannerGfxInterval = 33

Available when connected, always up-to-date



ComplainAutobanCount = 34

Only available on request (=> requestServerVariables)



ComplainAutobanTime = 35

Only available on request (=> requestServerVariables)



ComplainRemoveTime = 36

Only available on request (=> requestServerVariables)



MinClientsInChannelBeforeForcedSilence = 37

Only available on request (=> requestServerVariables)



PrioritySpeakerDimmModificator = 38

Available when connected, always up-to-date



Id = 39

Available when connected



AntifloodPointsTickReduce = 40

Only available on request (=> requestServerVariables)



AntifloodPointsNeededCommandBlock = 41

Only available on request (=> requestServerVariables)



AntifloodPointsNeededIpBlock = 42

Only available on request (=> requestServerVariables)



ClientConnections = 43

Only available on request (=> requestServerVariables)



QueryClientConnections = 44

Only available on request (=> requestServerVariables)



HostbuttonTooltip = 45

Available when connected, always up-to-date



HostbuttonUrl = 46

Available when connected, always up-to-date



HostbuttonGfxUrl = 47

Available when connected, always up-to-date



QueryclientsOnline = 48

Only available on request (=> requestServerVariables)



DownloadQuota = 49

Only available on request (=> requestServerVariables)



UploadQuota = 50

Only available on request (=> requestServerVariables)



MonthBytesDownloaded = 51

Only available on request (=> requestServerVariables)



MonthBytesUploaded = 52

Only available on request (=> requestServerVariables)



TotalBytesDownloaded = 53

Only available on request (=> requestServerVariables)



TotalBytesUploaded = 54

Only available on request (=> requestServerVariables)



Port = 55

Only available on request (=> requestServerVariables)



Autostart = 56

Only available on request (=> requestServerVariables)



MachineId = 57

Only available on request (=> requestServerVariables)



NeededIdentitySecurityLevel = 58

Only available on request (=> requestServerVariables)



LogClient = 59

Only available on request (=> requestServerVariables)



LogQuery = 60

Only available on request (=> requestServerVariables)



LogChannel = 61

Only available on request (=> requestServerVariables)



LogPermissions = 62

Only available on request (=> requestServerVariables)



LogServer = 63

Only available on request (=> requestServerVariables)



LogFiletransfer = 64

Integer. Read/Write. Boolean (1/0) indicating whether to include file transfer activities (uploading or downloading of files) in the server log. Always available.



MinClientVersion = 65

Only available on request (=> requestServerVariables)



NamePhonetic = 66

Available when connected, always up-to-date



IconId = 67

Available when connected, always up-to-date



ReservedSlots = 68

Available when connected, always up-to-date



TotalPacketlossSpeech = 69

Only available on request (=> requestServerVariables)



TotalPacketlossKeepalive = 70

Only available on request (=> requestServerVariables)



TotalPacketlossControl = 71

Only available on request (=> requestServerVariables)



TotalPacketlossTotal = 72

Only available on request (=> requestServerVariables)



TotalPing = 73

Only available on request (=> requestServerVariables)



Ip = 74

Internal use | contains only ONE binded ip



WeblistEnabled = 75

Only available on request (=> requestServerVariables)



AutogeneratedPrivilegekey = 76

Internal use



AskForPrivilegekey = 77

Available when connected



HostbannerMode = 78

Available when connected, always up-to-date



ChannelTempDeleteDelayDefault = 79

Available when connected, always up-to-date



MinAndroidVersion = 80

Only available on request (=> requestServerVariables)



MinIosVersion = 81

Only available on request (=> requestServerVariables)



MinWinphoneVersion = 82

Only available on request (=> requestServerVariables)



Nickname = 83

Available when connected, always up-to-date



AccountingToken = 84

Internal use, contains base64 encoded token data



ProtocolVerifyKeypair = 85

Internal use



AntifloodPointsNeededPluginBlock = 86

Only available on request (=> requestServerVariables)



CapabilityExtensions = 87

available when connected, not updated while connected



StorageQuota = 88

Allowed filetransfer storage on this server (including chat attachments) in megabytes



WebrtcCertificate = 89

internal use



WebrtcPrivateKey = 90

internal use



Uuid = 91

the uuid of the server (uuid v5 of VIRTUALSERVER_UNIQUE_IDENTIFIER)



AdministrativeDomain = 92

The domain which is responsible for this teamspeak server (which hosts its .well-known file)



CanonicalName = 93

The canonical name under which the server is reachable



MytsidConnectOnly = 94

Only clients that have a valid mytsid can connect



MaxHomebases = 95

How many matrix homebases this virtual server supports. -1 = no limit



HomebaseStorageQuota = 96

Allowed filetransfer storage for homebase attachments in megabytes



Endmarker = 97