Error

Enum Error 

#[repr(u32)]
pub enum Error {
Show 235 variants Ok = 0, Undefined = 1, NotImplemented = 2, OkNoUpdate = 3, DontNotify = 4, LibTimeLimitReached = 5, OutOfMemory = 6, Canceled = 7, CommandNotFound = 256, UnableToBindNetworkPort = 257, NoNetworkPortAvailable = 258, PortAlreadyInUse = 259, ClientInvalidId = 512, ClientNicknameInuse = 513, ClientProtocolLimitReached = 515, ClientInvalidType = 516, ClientAlreadySubscribed = 517, ClientNotLoggedIn = 518, ClientCouldNotValidateIdentity = 519, ClientInvalidPassword = 520, ClientTooManyClonesConnected = 521, ClientVersionOutdated = 522, ClientIsOnline = 523, ClientIsFlooding = 524, ClientHacked = 525, ClientCannotVerifyNow = 526, ClientLoginNotPermitted = 527, ClientNotSubscripted = 528, ChannelInvalidId = 768, ChannelProtocolLimitReached = 769, ChannelAlreadyIn = 770, ChannelnameInuse = 771, ChannelNotEmpty = 772, ChannelCannotDeleteDefault = 773, ChannelDefaultRequirePermanent = 774, ChannelInvalidFlags = 775, ChannelParentNotPermanent = 776, ChannelMaxclientsReached = 777, ChannelMaxfamilyReached = 778, ChannelInvalidOrder = 779, ChannelNoFiletransferSupported = 780, ChannelInvalidPassword = 781, ChannelIsPrivateChannel = 782, ChannelInvalidSecurityHash = 783, ServerInvalidId = 1_024, ServerRunning = 1_025, ServerIsShuttingDown = 1_026, ServerMaxclientsReached = 1_027, ServerInvalidPassword = 1_028, ServerDeploymentActive = 1_029, ServerUnableToStopOwnServer = 1_030, ServerIsVirtual = 1_031, ServerWrongMachineid = 1_032, ServerIsNotRunning = 1_033, ServerIsBooting = 1_034, ServerStatusInvalid = 1_035, ServerModalQuit = 1_036, ServerVersionOutdated = 1_037, ServerDuplicatedRunning = 1_038, ServerTimeDifferenceTooLarge = 1_039, ServerBlacklisted = 1_040, ServerShutdown = 1_041, Database = 1_280, DatabaseEmptyResult = 1_281, DatabaseDuplicateEntry = 1_282, DatabaseNoModifications = 1_283, DatabaseConstraint = 1_284, DatabaseReinvoke = 1_285, ParameterQuote = 1_536, ParameterInvalidCount = 1_537, ParameterInvalid = 1_538, ParameterNotFount = 1_539, ParameterConvert = 1_540, ParameterInvalidSize = 1_541, ParameterMissing = 1_542, ParameterChecksum = 1_543, VsCritical = 1_792, ConnectionLost = 1_793, NotConnected = 1_794, NoCachedConnectionInfo = 1_795, CurrentlyNotPossible = 1_796, FailedConnectionInitialisation = 1_797, CouldNotResolveHostname = 1_798, InvalidServerConnectionoHandlerId = 1_799, CouldNotInitialiseInputManager = 1_800, ClientlibraryNotInitialised = 1_801, ServerlibraryNotInitialised = 1_802, WhisperTooManyTargets = 1_803, WhisperNoTargets = 1_804, ConnectionIpProtocolMissing = 1_805, IllegalServerLicense = 1_807, FileInvalidName = 2_048, FileInvalidPermissions = 2_049, FileAlreadyExists = 2_050, FileNotFound = 2_051, FileIoError = 2_052, FileInvalidTransferId = 2_053, FileInvalidPath = 2_054, FileNoFilesAvailable = 2_055, FileOverwriteExcludesResume = 2_056, FileInvalidSize = 2_057, FileAlreadyInUse = 2_058, FileCouldNotOpenConnection = 2_059, FileNoSpaceLeftOnDevice = 2_060, FileExceedsFileSystemMaximumSize = 2_061, FileTransferConnectionTimeout = 2_062, FileConnectionLost = 2_063, FileExceedsSuppliedSize = 2_064, FileTransferComplete = 2_065, FileTransferCanceled = 2_066, FileTransferInterrupted = 2_067, FileTransferServerQuotaExceeded = 2_068, FileTransferClientQuotaExceeded = 2_069, FileTransferReset = 2_070, FileTransferLimitReached = 2_071, FileInvalidStorageClass = 2_072, FileInvalidDimension = 2_073, FileTransferChannelQuotaExceeded = 2_074, SoundPreprocessorDisabled = 2_304, SoundInternalPreprocessor = 2_305, SoundInternalEncoder = 2_306, SoundInternalPlayback = 2_307, SoundNoCaptureDeviceAvailable = 2_308, SoundNoPlaybackDeviceAvailable = 2_309, SoundCouldNotOpenCaptureDevice = 2_310, SoundCouldNotOpenPlaybackDevice = 2_311, SoundHandlerHasDevice = 2_312, SoundInvalidCaptureDevice = 2_313, SoundInvalidPlaybackDevice = 2_314, SoundInvalidWave = 2_315, SoundUnsupportedWave = 2_316, SoundOpenWave = 2_317, SoundInternalCapture = 2_318, SoundDeviceInUse = 2_319, SoundDeviceAlreadyRegisterred = 2_320, SoundUnknownDevice = 2_321, SoundUnsupportedFrequency = 2_322, SoundInvalidChannelCount = 2_323, SoundReadWave = 2_324, SoundNeedMoreData = 2_325, SoundDeviceBusy = 2_326, SoundNoData = 2_327, SoundChannelMaskMismatch = 2_328, PermissionsInvalidGroupId = 2_560, PermissionsDuplicateEntry = 2_561, PermissionsInvalidPermId = 2_562, PermissionsEmptyResult = 2_563, PermissionsDefaultGroupForbidden = 2_564, PermissionsInvalidSize = 2_565, PermissionsInvalidValue = 2_566, PermissionsGroupNotEmpty = 2_567, PermissionsClientInsufficient = 2_568, PermissionsInsufficientGroupPower = 2_569, PermissionsInsufficientPermissionPower = 2_570, PermissionsTemplateGroupIsUsed = 2_571, Permissions = 2_572, PermissionUsedByIntegration = 2_573, AccountingVirtualserverLimitReached = 2_816, AccountingSlotLimitReached = 2_817, AccountingLicenseFileNotFound = 2_818, AccountingLicenseDateNotOk = 2_819, AccountingUnableToConnectToServer = 2_820, AccountingUnknownError = 2_821, AcountingServerError = 2_822, AccountingInstanceLimitReached = 2_823, AccountingInstanceCheckError = 2_824, AccountingLicenseFileInvalid = 2_825, AccountingRunningElsewhere = 2_826, AccountingInstanceDuplicated = 2_827, AccountingAlreadyStarted = 2_828, AccountingNotStarted = 2_829, AccountingToManyStarts = 2_830, MessageInvalidId = 3_072, BanInvalidId = 3_328, ConnectFailedBanned = 3_329, RenameFailedBanned = 3_330, BanFlooding = 3_331, TtsUnableToInitialize = 3_584, PrivilegeKeyInvalid = 3_840, VoipPjsua = 4_096, VoipAlreadyInitialized = 4_097, VoipTooManyAccounts = 4_098, VoipInvalidAccount = 4_099, VoipInternalError = 4_100, VoipInvalidConnectionId = 4_101, VoipCannotAnswerInitiatedCall = 4_102, VoipNotInitialized = 4_103, ProvisioningInvalidPassword = 4_352, ProvisioningInvalidRequest = 4_353, ProvisioningNoSlotsAvailable = 4_354, ProvisioningPoolMissing = 4_355, ProvisioningPoolUnkown = 4_356, ProvisioningUnknownIpLocation = 4_357, ProvisioningInternalTriedExceeded = 4_358, ProvisioningTooManySlotsRequested = 4_359, ProvisioningTooManyReserved = 4_360, ProvisioningCouldNotConnect = 4_361, ProvisioningAuthServerNotConnected = 4_368, ProvisioningAuthDataTooLarge = 4_369, ProvisioningAlreadyInitialized = 4_370, ProvisioningNotInitialized = 4_371, ProvisioningConnecting = 4_372, ProvisioningAlreadyConnected = 4_373, ProvisioningNotConnected = 4_374, ProvisioningIoError = 4_375, ProvisioningInvalidTimeout = 4_376, ProvisioningTs3severNotFound = 4_377, ProvisioningNoPermission = 4_378, InvalidMytsidData = 4_608, InvalidIntegration = 4_609, MytsidNeeded = 4_610, Ed25519RngFail = 4_864, Ed25519SignatureInvalid = 4_865, Ed25519InvalidKey = 4_866, Ed25519UnableToCreateValidKey = 4_867, Ed25519OutOfMemory = 4_868, Ed25519Exists = 4_869, Ed25519ReadBeyondEof = 4_870, Ed25519WriteBeyondEof = 4_871, Ed25519Version = 4_872, Ed25519Invalid = 4_873, Ed25519InvalidDate = 4_874, Ed25519Unauthorized = 4_875, Ed25519InvalidType = 4_876, Ed25519AddressNomatch = 4_877, Ed25519NotValidYet = 4_878, Ed25519Expired = 4_879, Ed25519IndexOutOfRange = 4_880, Ed25519InvalidSize = 4_881, ApikeyOutofscope = 5_120, ApikeyCryptoError = 5_121, ApikeyInvalid = 5_122, ApikeyInvalidId = 5_123, ApikeyMissing = 5_124, HomebaseNoSlotsAvailable = 5_376,
}

Variants



Ok = 0

General Indicates success.



Undefined = 1



NotImplemented = 2

The attempted operation is not available in this context



OkNoUpdate = 3

Indicates success, but no change occurred. Returned for example upon flushing (e.g. using ts3client_flushChannelUpdates) when all indicated changes already matched the current state.



DontNotify = 4



LibTimeLimitReached = 5



OutOfMemory = 6

Not enough system memory to perform operation



Canceled = 7



CommandNotFound = 256

Dunno



UnableToBindNetworkPort = 257

Unspecified failure to create a listening port



NoNetworkPortAvailable = 258

Failure to initialize a listening port for FileTransfer



PortAlreadyInUse = 259

Specified port is already in use by a different application



ClientInvalidId = 512

Client Client no longer connected



ClientNicknameInuse = 513

Client name is already in use. Client names must be unique



ClientProtocolLimitReached = 515

Too many clients on the server



ClientInvalidType = 516

Function called for normal clients that is only available for query clients or vice versa



ClientAlreadySubscribed = 517

Attempting to subscribe to a channel already subsribed to



ClientNotLoggedIn = 518



ClientCouldNotValidateIdentity = 519

Identity not valid or insufficient security level



ClientInvalidPassword = 520



ClientTooManyClonesConnected = 521



ClientVersionOutdated = 522

Server requires newer client version as determined by the min_client_version properties



ClientIsOnline = 523



ClientIsFlooding = 524

Triggered flood protection. Further information is supplied in the extra message if applicable.



ClientHacked = 525



ClientCannotVerifyNow = 526



ClientLoginNotPermitted = 527



ClientNotSubscripted = 528

Action is only available on subscribed channels



ChannelInvalidId = 768

Channel Channel does not exist on the server (any longer)



ChannelProtocolLimitReached = 769

Too many channels on the server



ChannelAlreadyIn = 770

Attempting to move a client or channel to its current channel



ChannelnameInuse = 771

Channel name is already taken by another channel. Channel names must be unique



ChannelNotEmpty = 772

Attempting to delete a channel with clients or sub channels in it



ChannelCannotDeleteDefault = 773

Default channel cannot be deleted. Set a new default channel first (see ts3client_setChannelVariableAsInt or ts3server_setChannelVariableAsInt )



ChannelDefaultRequirePermanent = 774

Attempt to set a non permanent channel as default channel. Set channel to permanent first (see ts3client_setChannelVariableAsInt or ts3server_setChannelVariableAsInt )



ChannelInvalidFlags = 775

Invalid combination of ChannelProperties, trying to remove CHANNEL_FLAG_DEFAULT or set a password on the default channel



ChannelParentNotPermanent = 776

Attempt to move a permanent channel into a non-permanent one, or set a channel to be permanent that is a sub channel of a non-permanent one



ChannelMaxclientsReached = 777

Channel is full as determined by its CHANNEL_MAXCLIENTS setting



ChannelMaxfamilyReached = 778

Channel tree is full as determined by its CHANNEL_MAXFAMILYCLIENTS setting



ChannelInvalidOrder = 779

Invalid value for the CHANNEL_ORDER property. The specified channel must exist on the server and be on the same level.



ChannelNoFiletransferSupported = 780

Invalid CHANNEL_FILEPATH set for the channel



ChannelInvalidPassword = 781

Channel has a password not matching the password supplied in the call



ChannelIsPrivateChannel = 782



ChannelInvalidSecurityHash = 783



ServerInvalidId = 1_024

Server Chosen virtual server does not exist or is offline



ServerRunning = 1_025

attempting to delete a server that is running. Stop the server before deleting it.



ServerIsShuttingDown = 1_026

Client disconnected because the server is going offline



ServerMaxclientsReached = 1_027

Given in the onConnectStatusChange event when the server has reached its maximum number of clients as defined by the \ref VIRTUALSERVER_MAXCLIENTS property



ServerInvalidPassword = 1_028

Specified server password is wrong. Provide the correct password in the \ref ts3client_startConnection / \ref ts3client_startConnectionWithChannelID call.



ServerDeploymentActive = 1_029



ServerUnableToStopOwnServer = 1_030



ServerIsVirtual = 1_031

Server is in virtual status. The attempted action is not possible in this state. Start the virtual server first.



ServerWrongMachineid = 1_032



ServerIsNotRunning = 1_033

Attempting to stop a server that is not online.



ServerIsBooting = 1_034



ServerStatusInvalid = 1_035



ServerModalQuit = 1_036



ServerVersionOutdated = 1_037

Attempt to connect to an outdated server version. The server needs to be updated.



ServerDuplicatedRunning = 1_038

This server is already running within the instance. Each virtual server may only exist once.



ServerTimeDifferenceTooLarge = 1_039



ServerBlacklisted = 1_040



ServerShutdown = 1_041



Database = 1_280

Database



DatabaseEmptyResult = 1_281



DatabaseDuplicateEntry = 1_282



DatabaseNoModifications = 1_283



DatabaseConstraint = 1_284



DatabaseReinvoke = 1_285



ParameterQuote = 1_536

Parameter



ParameterInvalidCount = 1_537

Attempt to flush changes without previously calling setVariableAs since the last flush



ParameterInvalid = 1_538

At least one of the supplied parameters did not meet the criteria for that parameter



ParameterNotFount = 1_539

Failure to supply all the necessary parameters



ParameterConvert = 1_540

Invalid type supplied for a parameter, such as passing a string (ie. “five”) that expects a number.



ParameterInvalidSize = 1_541

Value out of allowed range. Such as strings are too long/short or numeric values outside allowed range



ParameterMissing = 1_542

Neglecting to specify a required parameter



ParameterChecksum = 1_543

Attempting to deploy a modified snapshot



VsCritical = 1_792

Unsorted, needs further investigation Failure to create default channel



ConnectionLost = 1_793

Generic error with the connection.



NotConnected = 1_794

Attempting to call functions with a serverConnectionHandler that is not connected. You can use \ref ts3client_getConnectionStatus to check whether the connection handler is connected to a server



NoCachedConnectionInfo = 1_795

Attempting to query connection information (bandwidth usage, ping, etc) without requesting them first using \ref ts3client_requestConnectionInfo



CurrentlyNotPossible = 1_796

Requested information is not currently available. You may have to call \ref ts3client_requestClientVariables or \ref ts3client_requestServerVariables



FailedConnectionInitialisation = 1_797

No TeamSpeak server running on the specified IP address and port



CouldNotResolveHostname = 1_798

Failure to resolve the specified hostname to an IP address



InvalidServerConnectionoHandlerId = 1_799

Attempting to perform actions on a non-existent server connection handler



CouldNotInitialiseInputManager = 1_800

Not used



ClientlibraryNotInitialised = 1_801

Calling client library functions without successfully calling \ref ts3client_initClientLib before



ServerlibraryNotInitialised = 1_802

Calling server library functions without successfully calling \ref ts3server_initServerLib before



WhisperTooManyTargets = 1_803

Using a whisper list that contain more clients than the servers \ref VIRTUALSERVER_MIN_CLIENTS_IN_CHANNEL_BEFORE_FORCED_SILENCE property



WhisperNoTargets = 1_804

The active whisper list is empty or no clients matched the whisper list (e.g. all channels in the list are empty)



ConnectionIpProtocolMissing = 1_805

Invalid or unsupported protocol (e.g. attempting an IPv6 connection on an IPv4 only machine)



IllegalServerLicense = 1_807



FileInvalidName = 2_048

File transfer Invalid UTF8 string or not a valid file



FileInvalidPermissions = 2_049

Permissions prevent opening the file



FileAlreadyExists = 2_050

Target path already exists as a directory



FileNotFound = 2_051

Attempt to access or move non existing file



FileIoError = 2_052

Generic file input / output error



FileInvalidTransferId = 2_053

Attempt to get information about a file transfer after it has already been cleaned up. File transfer information is not available indefinitely after the transfer completed



FileInvalidPath = 2_054

specified path contains invalid characters or does not start with “/”



FileNoFilesAvailable = 2_055

Not used



FileOverwriteExcludesResume = 2_056

File overwrite and resume are mutually exclusive. Only one or neither can be 1.



FileInvalidSize = 2_057

Attempt to write more bytes than claimed file size.



FileAlreadyInUse = 2_058

File is currently not available, try again later.



FileCouldNotOpenConnection = 2_059

Generic failure in file transfer connection / other party did not conform to file transfer protocol



FileNoSpaceLeftOnDevice = 2_060

Operating system reports hard disk is full. May be caused by quota limitations.



FileExceedsFileSystemMaximumSize = 2_061

File is too large for the file system of the target device.



FileTransferConnectionTimeout = 2_062

Not used



FileConnectionLost = 2_063

File input / output timeout or connection failure



FileExceedsSuppliedSize = 2_064

Not used



FileTransferComplete = 2_065

Indicates successful completion



FileTransferCanceled = 2_066

Transfer was cancelled through @ref ts3client_haltTransfer



FileTransferInterrupted = 2_067

Transfer failed because the server is shutting down, or network connection issues



FileTransferServerQuotaExceeded = 2_068

Transfer terminated due to server bandwidth quota being exceeded. No client can transfer files.



FileTransferClientQuotaExceeded = 2_069

Attempt to transfer more data than allowed by this clients’ bandwidth quota. Other clients may continue to transfer files.



FileTransferReset = 2_070

Not used



FileTransferLimitReached = 2_071

Too many file transfers are in progress. Try again later



FileInvalidStorageClass = 2_072

TODO: Invalid storage class for HTTP FileTransfer (what is a storage class?)



FileInvalidDimension = 2_073

Avatar image exceeds maximum width or height accepted by the server.



FileTransferChannelQuotaExceeded = 2_074

Transfer failed because the channel quota was exceeded. Uploading to this channel is not possible, but other channels may be fine.



SoundPreprocessorDisabled = 2_304

Sound Cannot set or query pre processor variables with preprocessing disabled



SoundInternalPreprocessor = 2_305



SoundInternalEncoder = 2_306



SoundInternalPlayback = 2_307



SoundNoCaptureDeviceAvailable = 2_308

No audio capture devices are available



SoundNoPlaybackDeviceAvailable = 2_309

No audio playback devices are available



SoundCouldNotOpenCaptureDevice = 2_310

Error accessing audio device, or audio device does not support the requested mode



SoundCouldNotOpenPlaybackDevice = 2_311

Error accessing audio device, or audio device does not support the requested mode



SoundHandlerHasDevice = 2_312

Attempt to open a sound device on a connection handler which already has an open device. Close the already open device first using \ref ts3client_closeCaptureDevice or \ref ts3client_closePlaybackDevice



SoundInvalidCaptureDevice = 2_313

Attempt to use a device for capture that does not support capturing audio



SoundInvalidPlaybackDevice = 2_314

Attempt to use a device for playback that does not support playback of audio



SoundInvalidWave = 2_315

Attempt to use a non WAV file in \ref ts3client_playWaveFile or \ref ts3client_playWaveFileHandle



SoundUnsupportedWave = 2_316

Unsupported wave file used in \ref ts3client_playWaveFile or \ref ts3client_playWaveFileHandle.



SoundOpenWave = 2_317

Failure to open the specified sound file



SoundInternalCapture = 2_318



SoundDeviceInUse = 2_319

Attempt to unregister a custom device that is being used. Close the device first using \ref ts3client_closeCaptureDevice or \ref ts3client_closePlaybackDevice



SoundDeviceAlreadyRegisterred = 2_320

Attempt to register a custom device with a device id that has already been used in a previous call. Device ids must be unique.



SoundUnknownDevice = 2_321

Attempt to open, close, unregister or use a device which is not known. Custom devices must be registered before being used (see \ref ts3client_registerCustomDevice)



SoundUnsupportedFrequency = 2_322



SoundInvalidChannelCount = 2_323

Invalid device audio channel count, must be > 0



SoundReadWave = 2_324

Failure to read sound samples from an opened wave file. Is this a valid wave file?



SoundNeedMoreData = 2_325

for internal purposes only



SoundDeviceBusy = 2_326

for internal purposes only



SoundNoData = 2_327

Indicates there is currently no data for playback, e.g. nobody is speaking right now.



SoundChannelMaskMismatch = 2_328

Opening a device with an unsupported channel count



PermissionsInvalidGroupId = 2_560

Permissions



PermissionsDuplicateEntry = 2_561



PermissionsInvalidPermId = 2_562



PermissionsEmptyResult = 2_563



PermissionsDefaultGroupForbidden = 2_564



PermissionsInvalidSize = 2_565



PermissionsInvalidValue = 2_566



PermissionsGroupNotEmpty = 2_567



PermissionsClientInsufficient = 2_568

Not enough permissions to perform the requested activity



PermissionsInsufficientGroupPower = 2_569



PermissionsInsufficientPermissionPower = 2_570



PermissionsTemplateGroupIsUsed = 2_571



Permissions = 2_572

Permissions to use sound device not granted by operating system, e.g. Windows denied microphone access.



PermissionUsedByIntegration = 2_573



AccountingVirtualserverLimitReached = 2_816

Accounting Attempt to use more virtual servers than allowed by the license



AccountingSlotLimitReached = 2_817

Attempt to set more slots than allowed by the license



AccountingLicenseFileNotFound = 2_818

Not used



AccountingLicenseDateNotOk = 2_819

License expired or not valid yet



AccountingUnableToConnectToServer = 2_820

Failure to communicate with accounting backend



AccountingUnknownError = 2_821

Failure to write update license file



AcountingServerError = 2_822

Not used



AccountingInstanceLimitReached = 2_823

More than one process of the server is running



AccountingInstanceCheckError = 2_824

Shared memory access failure.



AccountingLicenseFileInvalid = 2_825

License is not a TeamSpeak license



AccountingRunningElsewhere = 2_826

A copy of this server is already running in another instance. Each server may only exist once.



AccountingInstanceDuplicated = 2_827

A copy of this server is running already in this process. Each server may only exist once.



AccountingAlreadyStarted = 2_828

Attempt to start a server that is already running



AccountingNotStarted = 2_829



AccountingToManyStarts = 2_830

Starting instance / virtual servers too often in too short a time period



MessageInvalidId = 3_072

Messages



BanInvalidId = 3_328

Ban



ConnectFailedBanned = 3_329



RenameFailedBanned = 3_330



BanFlooding = 3_331



TtsUnableToInitialize = 3_584

Text to speech



PrivilegeKeyInvalid = 3_840

Privilege key



VoipPjsua = 4_096

Voip



VoipAlreadyInitialized = 4_097



VoipTooManyAccounts = 4_098



VoipInvalidAccount = 4_099



VoipInternalError = 4_100



VoipInvalidConnectionId = 4_101



VoipCannotAnswerInitiatedCall = 4_102



VoipNotInitialized = 4_103



ProvisioningInvalidPassword = 4_352

Provisioning server



ProvisioningInvalidRequest = 4_353



ProvisioningNoSlotsAvailable = 4_354



ProvisioningPoolMissing = 4_355



ProvisioningPoolUnkown = 4_356



ProvisioningUnknownIpLocation = 4_357



ProvisioningInternalTriedExceeded = 4_358



ProvisioningTooManySlotsRequested = 4_359



ProvisioningTooManyReserved = 4_360



ProvisioningCouldNotConnect = 4_361



ProvisioningAuthServerNotConnected = 4_368



ProvisioningAuthDataTooLarge = 4_369



ProvisioningAlreadyInitialized = 4_370



ProvisioningNotInitialized = 4_371



ProvisioningConnecting = 4_372



ProvisioningAlreadyConnected = 4_373



ProvisioningNotConnected = 4_374



ProvisioningIoError = 4_375



ProvisioningInvalidTimeout = 4_376



ProvisioningTs3severNotFound = 4_377



ProvisioningNoPermission = 4_378



InvalidMytsidData = 4_608

Mytsid - client



InvalidIntegration = 4_609



MytsidNeeded = 4_610



Ed25519RngFail = 4_864

Ed25519



Ed25519SignatureInvalid = 4_865



Ed25519InvalidKey = 4_866



Ed25519UnableToCreateValidKey = 4_867



Ed25519OutOfMemory = 4_868



Ed25519Exists = 4_869



Ed25519ReadBeyondEof = 4_870



Ed25519WriteBeyondEof = 4_871



Ed25519Version = 4_872



Ed25519Invalid = 4_873



Ed25519InvalidDate = 4_874



Ed25519Unauthorized = 4_875



Ed25519InvalidType = 4_876



Ed25519AddressNomatch = 4_877



Ed25519NotValidYet = 4_878



Ed25519Expired = 4_879



Ed25519IndexOutOfRange = 4_880



Ed25519InvalidSize = 4_881



ApikeyOutofscope = 5_120



ApikeyCryptoError = 5_121



ApikeyInvalid = 5_122



ApikeyInvalidId = 5_123



ApikeyMissing = 5_124



HomebaseNoSlotsAvailable = 5_376