Enum ts3plugin_sys::plugin_definitions::ConfigureOffer [] [src]

#[repr(C)]
pub enum ConfigureOffer { No, NewThread, QtThread, }

Return values for offersConfigure

Variants

Plugin does not implement ts3plugin_configure

Plugin does implement ts3plugin_configure and requests to run this function in an own thread

Plugin does implement ts3plugin_configure and requests to run this function in the Qt GUI thread