Enum ts3plugin_sys::public_definitions::ChannelProperties [] [src]

#[repr(C)]
pub enum ChannelProperties { Name, Topic, Description, Password, Codec, CodecQuality, MaxClients, MaxFamilyClients, Order, FlagPermanent, FlagSemiPermanent, FlagDefault, FlagPassword, CodecLatencyFactor, CodecIsUnencrypted, SecuritySalt, DeleteDelay, Dummy2, Dummy3, Dummy4, Dummy5, Dummy6, Dummy7, FlagMaxClientsUnlimited, FlagMaxFamilyClientsUnlimited, FlagMaxFamilyClientsInherited, FlagAreSubscribed, Filepath, NeededTalkPower, ForcedSilence, NamePhonetic, IconId, FlagPrivate, Endmarker, }

Variants

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Must be requested (=> requestChannelDescription)

Not available client side

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Not available client side, not used in teamspeak, only SDK. Sets the options+salt for security hash.

How many seconds to wait before deleting this channel

Rare properties

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Only available client side, stores whether we are subscribed to this channel

Not available client side, the folder used for file-transfers for this channel

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date

Available for all channels that are "in view", always up-to-date