Enum ts3plugin_sys::public_definitions::ChannelProperties
[−]
[src]
#[repr(C)]pub enum ChannelProperties { Name, Topic, Description, Password, Codec, CodecQuality, MaxClients, MaxFamilyClients, Order, FlagPermanent, FlagSemiPermanent, FlagDefault, FlagPassword, CodecLatencyFactor, CodecIsUnencrypted, SecuritySalt, DeleteDelay, Dummy2, Dummy3, Dummy4, Dummy5, Dummy6, Dummy7, FlagMaxClientsUnlimited, FlagMaxFamilyClientsUnlimited, FlagMaxFamilyClientsInherited, FlagAreSubscribed, Filepath, NeededTalkPower, ForcedSilence, NamePhonetic, IconId, FlagPrivate, Endmarker, }
Variants
NameAvailable for all channels that are "in view", always up-to-date
TopicAvailable for all channels that are "in view", always up-to-date
DescriptionMust be requested (=> requestChannelDescription)
PasswordNot available client side
CodecAvailable for all channels that are "in view", always up-to-date
CodecQualityAvailable for all channels that are "in view", always up-to-date
MaxClientsAvailable for all channels that are "in view", always up-to-date
MaxFamilyClientsAvailable for all channels that are "in view", always up-to-date
OrderAvailable for all channels that are "in view", always up-to-date
FlagPermanentAvailable for all channels that are "in view", always up-to-date
FlagSemiPermanentAvailable for all channels that are "in view", always up-to-date
FlagDefaultAvailable for all channels that are "in view", always up-to-date
FlagPasswordAvailable for all channels that are "in view", always up-to-date
CodecLatencyFactorAvailable for all channels that are "in view", always up-to-date
CodecIsUnencryptedAvailable for all channels that are "in view", always up-to-date
SecuritySaltNot available client side, not used in teamspeak, only SDK. Sets the options+salt for security hash.
DeleteDelayHow many seconds to wait before deleting this channel
Dummy2Rare properties
Dummy3Dummy4Dummy5Dummy6Dummy7FlagMaxClientsUnlimitedAvailable for all channels that are "in view", always up-to-date
FlagMaxFamilyClientsUnlimitedAvailable for all channels that are "in view", always up-to-date
FlagMaxFamilyClientsInheritedAvailable for all channels that are "in view", always up-to-date
FlagAreSubscribedOnly available client side, stores whether we are subscribed to this channel
FilepathNot available client side, the folder used for file-transfers for this channel
NeededTalkPowerAvailable for all channels that are "in view", always up-to-date
ForcedSilenceAvailable for all channels that are "in view", always up-to-date
NamePhoneticAvailable for all channels that are "in view", always up-to-date
IconIdAvailable for all channels that are "in view", always up-to-date
FlagPrivateAvailable for all channels that are "in view", always up-to-date
EndmarkerTrait Implementations
impl Debug for ChannelProperties[src]
impl PartialEq for ChannelProperties[src]
fn eq(&self, __arg_0: &ChannelProperties) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for ChannelProperties[src]
impl Clone for ChannelProperties[src]
fn clone(&self) -> ChannelProperties
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more