ClientProperties

Enum ClientProperties 

#[repr(C)]
pub enum ClientProperties {
Show 70 variants UniqueIdentifier = 0, Nickname = 1, Version = 2, Platform = 3, FlagTalking = 4, InputMuted = 5, OutputMuted = 6, OutputOnlyMuted = 7, InputHardware = 8, OutputHardware = 9, InputDeactivated = 10, IdleTime = 11, DefaultChannel = 12, DefaultChannelPassword = 13, ServerPassword = 14, MetaData = 15, IsMuted = 16, IsRecording = 17, VolumeModificator = 18, VersionSign = 19, SecurityHash = 20, EncryptionCiphers = 21, Dummy4 = 22, Dummy5 = 23, Dummy6 = 24, Dummy7 = 25, Dummy8 = 26, Dummy9 = 27, KeyOffset = 28, LastVarRequest = 29, LoginName = 30, LoginPassword = 31, DatabaseId = 32, ChannelGroupId = 33, Servergroups = 34, Created = 35, Lastconnected = 36, Totalconnections = 37, Away = 38, AwayMessage = 39, Type = 40, FlagAvatar = 41, TalkPower = 42, TalkRequest = 43, TalkRequestMsg = 44, Description = 45, IsTalker = 46, MonthBytesUploaded = 47, MonthBytesDownloaded = 48, TotalBytesUploaded = 49, TotalBytesDownloaded = 50, IsPrioritySpeaker = 51, UnreadMessages = 52, NicknamePhonetic = 53, NeededServerqueryViewPower = 54, DefaultToken = 55, IconId = 56, IsChannelCommander = 57, Country = 58, ChannelGroupInheritedChannelId = 59, Badges = 60, MyteamspeakId = 61, Integrations = 62, ActiveIntegrationsInfo = 63, MytsAvatar = 64, SignedBadges = 65, PermissionHints = 66, UserTag = 67, Endmarker = 68, HwId = 127,
}

Variants



UniqueIdentifier = 0

String. Read only. Public Identity, can be used to identify a client installation. Remains identical as long as the client keeps using the same identity. Available for visible clients.



Nickname = 1

String. Read/Write. Display name of the client. Available for visible clients.



Version = 2

String. Read only. Version String of the client used. For clients other than ourself this needs to be requested (ts3client_requestClientVariables).



Platform = 3

String. Read only. Operating system used by the client. For other clients other than ourself this needs to be requested (ts3client_requestClientVariables).



FlagTalking = 4

Integer. Read only. Whether the client is talking. Available on clients that are either whispering to us, or in our channel.



InputMuted = 5

Integer. Read/Write. Microphone mute status. Available for visible clients. One of the values from the MuteInputStatus enum.



OutputMuted = 6

Integer. Read only. Speaker mute status. Speaker mute implies microphone mute. Available for visible clients. One of the values from the MuteOutputStatus enum.



OutputOnlyMuted = 7

Integer. Read only. Speaker mute status. Microphone may be active. Available for visible clients. One of the values from the MuteOutputStatus enum.



InputHardware = 8

Integer. Read only. Indicates whether a capture device is open. Available for visible clients. One of the values from the HardwareInputStatus enum.



OutputHardware = 9

Integer. Read only. Indicates whether a playback device is open. Available for visible clients. One of the values from the HardwareOutputStatus enum.



InputDeactivated = 10

Integer. Read/Write. Not available server side. Local microphone mute status. Available only for own client. Used to implement Push To Talk. One of the values from the InputDeactivationStatus enum.



IdleTime = 11

UInt64. Read only. Seconds since last activity. Available only for own client.



DefaultChannel = 12

String. Read only. User specified channel they joined when connecting to the server. Available only for own client.



DefaultChannelPassword = 13

String. Read only. User specified channel password for the channel they attempted to join when connecting to the server. Available only for own client.



ServerPassword = 14

String. Read only. User specified server password. Available only for own client.



MetaData = 15

String. Read/Write. Can be used to store up to 4096 bytes of information on clients. Not used by TeamSpeak. Available for visible clients.



IsMuted = 16

Integer. Read only. Not available server side. Indicates whether we have muted the client using ts3client_requestMuteClients. Available for visible clients other than ourselves.



IsRecording = 17

Integer. Read only. Indicates whether the client is recording incoming audio. Available for visible clients.



VolumeModificator = 18

Integer. Read only. Volume adjustment for this client as set by ts3client_setClientVolumeModifier. Available for visible clients.



VersionSign = 19

String. Read only. TeamSpeak internal signature.



SecurityHash = 20

String. Read/Write. This clients security hash. Not used by TeamSpeak, SDK only. Hash is provided by an outside source. A channel will use the security salt + other client data to calculate a hash, which must be the same as the one provided here. See SDK documentation about Client / Channel Security Hashes for more details.



EncryptionCiphers = 21

String. Read only. SDK only. List of available ciphers this client can use.



Dummy4 = 22

Rare properties



Dummy5 = 23



Dummy6 = 24



Dummy7 = 25



Dummy8 = 26



Dummy9 = 27



KeyOffset = 28

Internal use



LastVarRequest = 29

Internal use



LoginName = 30

Used for serverquery clients, makes no sense on normal clients currently



LoginPassword = 31

Used for serverquery clients, makes no sense on normal clients currently



DatabaseId = 32

Automatically up-to-date for any client “in view”, only valid with PERMISSION feature, holds database client id



ChannelGroupId = 33

Automatically up-to-date for any client “in view”, only valid with PERMISSION feature, holds database client id



Servergroups = 34

Automatically up-to-date for any client “in view”, only valid with PERMISSION feature, holds all servergroups client belongs too



Created = 35

This needs to be requested (=> requestClientVariables), first time this client connected to this server



Lastconnected = 36

This needs to be requested (=> requestClientVariables), last time this client connected to this server



Totalconnections = 37

This needs to be requested (=> requestClientVariables), how many times this client connected to this server



Away = 38

Automatically up-to-date for any client “in view”, this clients away status



AwayMessage = 39

Automatically up-to-date for any client “in view”, this clients away status



Type = 40

Automatically up-to-date for any client “in view”, determines if this is a real client or a server-query connection



FlagAvatar = 41

Automatically up-to-date for any client “in view”, this client got an avatar



TalkPower = 42

Automatically up-to-date for any client “in view”, only valid with PERMISSION feature, holds database client id



TalkRequest = 43

Automatically up-to-date for any client “in view”, only valid with PERMISSION feature, holds timestamp where client requested to talk



TalkRequestMsg = 44

Automatically up-to-date for any client “in view”, only valid with PERMISSION feature, holds matter for the request



Description = 45

Automatically up-to-date for any client “in view”



IsTalker = 46

Automatically up-to-date for any client “in view”



MonthBytesUploaded = 47

This needs to be requested (=> requestClientVariables)



MonthBytesDownloaded = 48

This needs to be requested (=> requestClientVariables)



TotalBytesUploaded = 49

This needs to be requested (=> requestClientVariables)



TotalBytesDownloaded = 50

This needs to be requested (=> requestClientVariables)



IsPrioritySpeaker = 51

Automatically up-to-date for any client “in view”



UnreadMessages = 52

Automatically up-to-date for any client “in view”



NicknamePhonetic = 53

Automatically up-to-date for any client “in view”



NeededServerqueryViewPower = 54

Automatically up-to-date for any client “in view”



DefaultToken = 55

Only usable for ourself, the default token we used to connect on our last connection attempt



IconId = 56

Automatically up-to-date for any client “in view”



IsChannelCommander = 57

Automatically up-to-date for any client “in view”



Country = 58

Automatically up-to-date for any client “in view”



ChannelGroupInheritedChannelId = 59

Automatically up-to-date for any client “in view”, only valid with PERMISSION feature, contains channel_id where the channel_group_id is set from



Badges = 60

Automatically up-to-date for any client “in view”, stores icons for partner badges



MyteamspeakId = 61

Automatically up-to-date for any client “in view”



Integrations = 62

Automatically up-to-date for any client “in view”



ActiveIntegrationsInfo = 63

Stores info from the myts server and contains the subscription info



MytsAvatar = 64



SignedBadges = 65



PermissionHints = 66



UserTag = 67

automatically up-to-date for any client “in view”, stores public chat user tag



Endmarker = 68



HwId = 127

(for clientlibv2) unique hardware id