Enum ts3plugin_sys::public_definitions::ClientProperties [] [src]

#[repr(C)]
pub enum ClientProperties { UniqueIdentifier, Nickname, Version, Platform, FlagTalking, InputMuted, OutputMuted, OutputOnlyMuted, InputHardware, OutputHardware, InputDeactivated, IdleTime, DefaultChannel, DefaultChannelPassword, ServerPassword, MetaData, IsMuted, IsRecording, VolumeModificator, VersionSign, SecurityHash, Dummy3, Dummy4, Dummy5, Dummy6, Dummy7, Dummy8, Dummy9, KeyOffset, LastVarRequest, LoginName, LoginPassword, DatabaseId, ChannelGroupId, Servergroups, Created, Lastconnected, Totalconnections, Away, AwayMessage, Type, FlagAvatar, TalkPower, TalkRequest, TalkRequestMsg, Description, IsTalker, MonthBytesUploaded, MonthBytesDownloaded, TotalBytesUploaded, TotalBytesDownloaded, IsPrioritySpeaker, UnreadMessages, NicknamePhonetic, NeededServerqueryViewPower, DefaultToken, IconId, IsChannelCommander, Country, ChannelGroupInheritedChannelId, Badges, Endmarker, }

Variants

Automatically up-to-date for any client "in view", can be used to identify this particular client installation

Automatically up-to-date for any client "in view"

For other clients than ourself, this needs to be requested (=> requestClientVariables)

For other clients than ourself, this needs to be requested (=> requestClientVariables)

Automatically up-to-date for any client that can be heard (in room / whisper)

Automatically up-to-date for any client "in view", this clients microphone mute status

Automatically up-to-date for any client "in view", this clients headphones/speakers/mic combined mute status

Automatically up-to-date for any client "in view", this clients headphones/speakers only mute status

Automatically up-to-date for any client "in view", this clients microphone hardware status (is the capture device opened?)

Automatically up-to-date for any client "in view", this clients headphone/speakers hardware status (is the playback device opened?)

Only usable for ourself, not propagated to the network

Internal use

Only usable for ourself, the default channel we used to connect on our last connection attempt

Internal use

Internal use

Automatically up-to-date for any client "in view", not used by TeamSpeak, free storage for sdk users

Only make sense on the client side locally, "1" if this client is currently muted by us, "0" if he is not

Automatically up-to-date for any client "in view"

Internal use

Sign

SDK use, not used by teamspeak. Hash is provided by an outside source. A channel will use the security salt + other client data to calculate a hash, which must be the same as the one provided here.

Rare properties

Internal use

Internal use

Used for serverquery clients, makes no sense on normal clients currently

Used for serverquery clients, makes no sense on normal clients currently

Automatically up-to-date for any client "in view", only valid with PERMISSION feature, holds database client id

Automatically up-to-date for any client "in view", only valid with PERMISSION feature, holds database client id

Automatically up-to-date for any client "in view", only valid with PERMISSION feature, holds all servergroups client belongs too

This needs to be requested (=> requestClientVariables), first time this client connected to this server

This needs to be requested (=> requestClientVariables), last time this client connected to this server

This needs to be requested (=> requestClientVariables), how many times this client connected to this server

Automatically up-to-date for any client "in view", this clients away status

Automatically up-to-date for any client "in view", this clients away status

Automatically up-to-date for any client "in view", determines if this is a real client or a server-query connection

Automatically up-to-date for any client "in view", this client got an avatar

Automatically up-to-date for any client "in view", only valid with PERMISSION feature, holds database client id

Automatically up-to-date for any client "in view", only valid with PERMISSION feature, holds timestamp where client requested to talk

Automatically up-to-date for any client "in view", only valid with PERMISSION feature, holds matter for the request

Automatically up-to-date for any client "in view"

Automatically up-to-date for any client "in view"

This needs to be requested (=> requestClientVariables)

This needs to be requested (=> requestClientVariables)

This needs to be requested (=> requestClientVariables)

This needs to be requested (=> requestClientVariables)

Automatically up-to-date for any client "in view"

Automatically up-to-date for any client "in view"

Automatically up-to-date for any client "in view"

Automatically up-to-date for any client "in view"

Only usable for ourself, the default token we used to connect on our last connection attempt

Automatically up-to-date for any client "in view"

Automatically up-to-date for any client "in view"

Automatically up-to-date for any client "in view"

Automatically up-to-date for any client "in view", only valid with PERMISSION feature, contains channel_id where the channel_group_id is set from

Automatically up-to-date for any client "in view", stores icons for partner badges