Enum ts3plugin_sys::public_definitions::ClientProperties
[−]
[src]
#[repr(C)]pub enum ClientProperties { UniqueIdentifier, Nickname, Version, Platform, FlagTalking, InputMuted, OutputMuted, OutputOnlyMuted, InputHardware, OutputHardware, InputDeactivated, IdleTime, DefaultChannel, DefaultChannelPassword, ServerPassword, MetaData, IsMuted, IsRecording, VolumeModificator, VersionSign, SecurityHash, Dummy3, Dummy4, Dummy5, Dummy6, Dummy7, Dummy8, Dummy9, KeyOffset, LastVarRequest, LoginName, LoginPassword, DatabaseId, ChannelGroupId, Servergroups, Created, Lastconnected, Totalconnections, Away, AwayMessage, Type, FlagAvatar, TalkPower, TalkRequest, TalkRequestMsg, Description, IsTalker, MonthBytesUploaded, MonthBytesDownloaded, TotalBytesUploaded, TotalBytesDownloaded, IsPrioritySpeaker, UnreadMessages, NicknamePhonetic, NeededServerqueryViewPower, DefaultToken, IconId, IsChannelCommander, Country, ChannelGroupInheritedChannelId, Badges, Endmarker, }
Variants
UniqueIdentifierAutomatically up-to-date for any client "in view", can be used to identify this particular client installation
NicknameAutomatically up-to-date for any client "in view"
VersionFor other clients than ourself, this needs to be requested (=> requestClientVariables)
PlatformFor other clients than ourself, this needs to be requested (=> requestClientVariables)
FlagTalkingAutomatically up-to-date for any client that can be heard (in room / whisper)
InputMutedAutomatically up-to-date for any client "in view", this clients microphone mute status
OutputMutedAutomatically up-to-date for any client "in view", this clients headphones/speakers/mic combined mute status
OutputOnlyMutedAutomatically up-to-date for any client "in view", this clients headphones/speakers only mute status
InputHardwareAutomatically up-to-date for any client "in view", this clients microphone hardware status (is the capture device opened?)
OutputHardwareAutomatically up-to-date for any client "in view", this clients headphone/speakers hardware status (is the playback device opened?)
InputDeactivatedOnly usable for ourself, not propagated to the network
IdleTimeInternal use
DefaultChannelOnly usable for ourself, the default channel we used to connect on our last connection attempt
DefaultChannelPasswordInternal use
ServerPasswordInternal use
MetaDataAutomatically up-to-date for any client "in view", not used by TeamSpeak, free storage for sdk users
IsMutedOnly make sense on the client side locally, "1" if this client is currently muted by us, "0" if he is not
IsRecordingAutomatically up-to-date for any client "in view"
VolumeModificatorInternal use
VersionSignSign
SecurityHashSDK use, not used by teamspeak. Hash is provided by an outside source. A channel will use the security salt + other client data to calculate a hash, which must be the same as the one provided here.
Dummy3Rare properties
Dummy4Dummy5Dummy6Dummy7Dummy8Dummy9KeyOffsetInternal use
LastVarRequestInternal use
LoginNameUsed for serverquery clients, makes no sense on normal clients currently
LoginPasswordUsed for serverquery clients, makes no sense on normal clients currently
DatabaseIdAutomatically up-to-date for any client "in view", only valid with PERMISSION feature, holds database client id
ChannelGroupIdAutomatically up-to-date for any client "in view", only valid with PERMISSION feature, holds database client id
ServergroupsAutomatically up-to-date for any client "in view", only valid with PERMISSION feature, holds all servergroups client belongs too
CreatedThis needs to be requested (=> requestClientVariables), first time this client connected to this server
LastconnectedThis needs to be requested (=> requestClientVariables), last time this client connected to this server
TotalconnectionsThis needs to be requested (=> requestClientVariables), how many times this client connected to this server
AwayAutomatically up-to-date for any client "in view", this clients away status
AwayMessageAutomatically up-to-date for any client "in view", this clients away status
TypeAutomatically up-to-date for any client "in view", determines if this is a real client or a server-query connection
FlagAvatarAutomatically up-to-date for any client "in view", this client got an avatar
TalkPowerAutomatically up-to-date for any client "in view", only valid with PERMISSION feature, holds database client id
TalkRequestAutomatically up-to-date for any client "in view", only valid with PERMISSION feature, holds timestamp where client requested to talk
TalkRequestMsgAutomatically up-to-date for any client "in view", only valid with PERMISSION feature, holds matter for the request
DescriptionAutomatically up-to-date for any client "in view"
IsTalkerAutomatically up-to-date for any client "in view"
MonthBytesUploadedThis needs to be requested (=> requestClientVariables)
MonthBytesDownloadedThis needs to be requested (=> requestClientVariables)
TotalBytesUploadedThis needs to be requested (=> requestClientVariables)
TotalBytesDownloadedThis needs to be requested (=> requestClientVariables)
IsPrioritySpeakerAutomatically up-to-date for any client "in view"
UnreadMessagesAutomatically up-to-date for any client "in view"
NicknamePhoneticAutomatically up-to-date for any client "in view"
NeededServerqueryViewPowerAutomatically up-to-date for any client "in view"
DefaultTokenOnly usable for ourself, the default token we used to connect on our last connection attempt
IconIdAutomatically up-to-date for any client "in view"
IsChannelCommanderAutomatically up-to-date for any client "in view"
CountryAutomatically up-to-date for any client "in view"
ChannelGroupInheritedChannelIdAutomatically up-to-date for any client "in view", only valid with PERMISSION feature, contains channel_id where the channel_group_id is set from
BadgesAutomatically up-to-date for any client "in view", stores icons for partner badges
EndmarkerTrait Implementations
impl Debug for ClientProperties[src]
impl PartialEq for ClientProperties[src]
fn eq(&self, __arg_0: &ClientProperties) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for ClientProperties[src]
impl Clone for ClientProperties[src]
fn clone(&self) -> ClientProperties
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more