Enum ts3plugin_sys::public_definitions::CodecType
[−]
[src]
#[repr(C)]pub enum CodecType { SpeexNarrowband, SpeexWideband, SpeexUltrawideband, CeltMono, OpusVoice, OpusMusic, }
Variants
SpeexNarrowbandMono, 16bit, 8kHz, bitrate dependent on the quality setting
SpeexWidebandMono, 16bit, 16kHz, bitrate dependent on the quality setting
SpeexUltrawidebandMono, 16bit, 32kHz, bitrate dependent on the quality setting
CeltMonoMono, 16bit, 48kHz, bitrate dependent on the quality setting
OpusVoiceMono, 16bit, 48kHz, bitrate dependent on the quality setting, optimized for voice
OpusMusicStereo, 16bit, 48kHz, bitrate dependent on the quality setting, optimized for music