Enum ts3plugin_sys::public_definitions::ConnectionProperties [] [src]

#[repr(C)]
pub enum ConnectionProperties { Ping, PingDeviation, ConnectedTime, IdleTime, ClientIp, ClientPort, ServerIp, ServerPort, PacketsSentSpeech, PacketsSentKeepalive, PacketsSentControl, PacketsSentTotal, BytesSentSpeech, BytesSentKeepalive, BytesSentControl, BytesSentTotal, PacketsReceivedSpeech, PacketsReceivedKeepalive, PacketsReceivedControl, PacketsReceivedTotal, BytesReceivedSpeech, BytesReceivedKeepalive, BytesReceivedControl, BytesReceivedTotal, PacketlossSpeech, PacketlossKeepalive, PacketlossControl, PacketlossTotal, Server2ClientPacketlossSpeech, Server2ClientPacketlossKeepalive, Server2ClientPacketlossControl, Server2ClientPacketlossTotal, Client2ServerPacketlossSpeech, Client2ServerPacketlossKeepalive, Client2ServerPacketlossControl, Client2ServerPacketlossTotal, BandwidthSentLastSecondSpeech, BandwidthSentLastSecondKeepalive, BandwidthSentLastSecondControl, BandwidthSentLastSecondTotal, BandwidthSentLastMinuteSpeech, BandwidthSentLastMinuteKeepalive, BandwidthSentLastMinuteControl, BandwidthSentLastMinuteTotal, BandwidthReceivedLastSecondSpeech, BandwidthReceivedLastSecondKeepalive, BandwidthReceivedLastSecondControl, BandwidthReceivedLastSecondTotal, BandwidthReceivedLastMinuteSpeech, BandwidthReceivedLastMinuteKeepalive, BandwidthReceivedLastMinuteControl, BandwidthReceivedLastMinuteTotal, Dummy0, Dummy1, Dummy2, Dummy3, Dummy4, Dummy5, Dummy6, Dummy7, Dummy8, Dummy9, FileTransferBandwidthSent, FiletransferBandwidthReceived, FiletransferBytesReceivedTotal, FiletransferBytesSentTotal, Endmarker, }

Variants

Average latency for a round trip through and back this connection

Standard deviation of the above average latency

How long the connection exists already

How long since the last action of this client

IP of this client (as seen from the server side)

Port of this client (as seen from the server side)

IP of the server (seen from the client side) - only available on yourself, not for remote clients, not available server side

Port of the server (seen from the client side) - only available on yourself, not for remote clients, not available server side

How many Speech packets were sent through this connection

How many packets were sent totally (this is PACKETS_SENT_SPEECH + PACKETS_SENT_KEEPALIVE + PACKETS_SENT_CONTROL)

The probability with which a packet round trip failed because a packet was lost

The probability with which a speech packet failed from the server to the client

Howmany bytes of speech packets we sent during the last second

Howmany bytes/s of speech packets we sent in average during the last minute

Rare properties

How many bytes per second are currently being sent by file transfers

Bow many bytes per second are currently being received by file transfers

How many bytes we received in total through file transfers

How many bytes we sent in total through file transfers