Enum ts3plugin_sys::public_definitions::ConnectionProperties
[−]
[src]
#[repr(C)]pub enum ConnectionProperties { Ping, PingDeviation, ConnectedTime, IdleTime, ClientIp, ClientPort, ServerIp, ServerPort, PacketsSentSpeech, PacketsSentKeepalive, PacketsSentControl, PacketsSentTotal, BytesSentSpeech, BytesSentKeepalive, BytesSentControl, BytesSentTotal, PacketsReceivedSpeech, PacketsReceivedKeepalive, PacketsReceivedControl, PacketsReceivedTotal, BytesReceivedSpeech, BytesReceivedKeepalive, BytesReceivedControl, BytesReceivedTotal, PacketlossSpeech, PacketlossKeepalive, PacketlossControl, PacketlossTotal, Server2ClientPacketlossSpeech, Server2ClientPacketlossKeepalive, Server2ClientPacketlossControl, Server2ClientPacketlossTotal, Client2ServerPacketlossSpeech, Client2ServerPacketlossKeepalive, Client2ServerPacketlossControl, Client2ServerPacketlossTotal, BandwidthSentLastSecondSpeech, BandwidthSentLastSecondKeepalive, BandwidthSentLastSecondControl, BandwidthSentLastSecondTotal, BandwidthSentLastMinuteSpeech, BandwidthSentLastMinuteKeepalive, BandwidthSentLastMinuteControl, BandwidthSentLastMinuteTotal, BandwidthReceivedLastSecondSpeech, BandwidthReceivedLastSecondKeepalive, BandwidthReceivedLastSecondControl, BandwidthReceivedLastSecondTotal, BandwidthReceivedLastMinuteSpeech, BandwidthReceivedLastMinuteKeepalive, BandwidthReceivedLastMinuteControl, BandwidthReceivedLastMinuteTotal, Dummy0, Dummy1, Dummy2, Dummy3, Dummy4, Dummy5, Dummy6, Dummy7, Dummy8, Dummy9, FileTransferBandwidthSent, FiletransferBandwidthReceived, FiletransferBytesReceivedTotal, FiletransferBytesSentTotal, Endmarker, }
Variants
PingAverage latency for a round trip through and back this connection
PingDeviationStandard deviation of the above average latency
ConnectedTimeHow long the connection exists already
IdleTimeHow long since the last action of this client
ClientIpIP of this client (as seen from the server side)
ClientPortPort of this client (as seen from the server side)
ServerIpIP of the server (seen from the client side) - only available on yourself, not for remote clients, not available server side
ServerPortPort of the server (seen from the client side) - only available on yourself, not for remote clients, not available server side
PacketsSentSpeechHow many Speech packets were sent through this connection
PacketsSentKeepalivePacketsSentControlPacketsSentTotalHow many packets were sent totally (this is PACKETS_SENT_SPEECH + PACKETS_SENT_KEEPALIVE + PACKETS_SENT_CONTROL)
BytesSentSpeechBytesSentKeepaliveBytesSentControlBytesSentTotalPacketsReceivedSpeechPacketsReceivedKeepalivePacketsReceivedControlPacketsReceivedTotalBytesReceivedSpeechBytesReceivedKeepaliveBytesReceivedControlBytesReceivedTotalPacketlossSpeechPacketlossKeepalivePacketlossControlPacketlossTotalThe probability with which a packet round trip failed because a packet was lost
Server2ClientPacketlossSpeechThe probability with which a speech packet failed from the server to the client
Server2ClientPacketlossKeepaliveServer2ClientPacketlossControlServer2ClientPacketlossTotalClient2ServerPacketlossSpeechClient2ServerPacketlossKeepaliveClient2ServerPacketlossControlClient2ServerPacketlossTotalBandwidthSentLastSecondSpeechHowmany bytes of speech packets we sent during the last second
BandwidthSentLastSecondKeepaliveBandwidthSentLastSecondControlBandwidthSentLastSecondTotalBandwidthSentLastMinuteSpeechHowmany bytes/s of speech packets we sent in average during the last minute
BandwidthSentLastMinuteKeepaliveBandwidthSentLastMinuteControlBandwidthSentLastMinuteTotalBandwidthReceivedLastSecondSpeechBandwidthReceivedLastSecondKeepaliveBandwidthReceivedLastSecondControlBandwidthReceivedLastSecondTotalBandwidthReceivedLastMinuteSpeechBandwidthReceivedLastMinuteKeepaliveBandwidthReceivedLastMinuteControlBandwidthReceivedLastMinuteTotalDummy0Rare properties
Dummy1Dummy2Dummy3Dummy4Dummy5Dummy6Dummy7Dummy8Dummy9FileTransferBandwidthSentHow many bytes per second are currently being sent by file transfers
FiletransferBandwidthReceivedBow many bytes per second are currently being received by file transfers
FiletransferBytesReceivedTotalHow many bytes we received in total through file transfers
FiletransferBytesSentTotalHow many bytes we sent in total through file transfers
EndmarkerTrait Implementations
impl Debug for ConnectionProperties[src]
impl PartialEq for ConnectionProperties[src]
fn eq(&self, __arg_0: &ConnectionProperties) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for ConnectionProperties[src]
impl Clone for ConnectionProperties[src]
fn clone(&self) -> ConnectionProperties
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more