Enum ts3plugin_sys::public_definitions::ServerInstancePropertiesRare [] [src]

#[repr(C)]
pub enum ServerInstancePropertiesRare { DatabaseVersion, FiletransferPort, ServerEntropy, MonthlyTimestamp, MaxDownloadTotalBandwidth, MaxUploadTotalBandwidth, GuestServerqueryGroup, ServerqueryFloodCommands, ServerqueryFloodTime, ServerqueryBanTime, TemplateServeradminGroup, TemplateServerdefaultGroup, TemplateChanneladminGroup, TemplateChannelDefaultGroup, PermissionsVersion, PendingConnectionsPerIp, Endmarker, }

Variants

How many commands we can issue while in the SERVERINSTANCE_SERVERQUERY_FLOOD_TIME window

Time window in seconds for max command execution check

How many seconds someone get banned if he floods