Enum ts3plugin_sys::public_definitions::ServerInstancePropertiesRare
[−]
[src]
#[repr(C)]pub enum ServerInstancePropertiesRare { DatabaseVersion, FiletransferPort, ServerEntropy, MonthlyTimestamp, MaxDownloadTotalBandwidth, MaxUploadTotalBandwidth, GuestServerqueryGroup, ServerqueryFloodCommands, ServerqueryFloodTime, ServerqueryBanTime, TemplateServeradminGroup, TemplateServerdefaultGroup, TemplateChanneladminGroup, TemplateChannelDefaultGroup, PermissionsVersion, PendingConnectionsPerIp, Endmarker, }
Variants
DatabaseVersionFiletransferPortServerEntropyMonthlyTimestampMaxDownloadTotalBandwidthMaxUploadTotalBandwidthGuestServerqueryGroupServerqueryFloodCommandsHow many commands we can issue while in the SERVERINSTANCE_SERVERQUERY_FLOOD_TIME window
ServerqueryFloodTimeTime window in seconds for max command execution check
ServerqueryBanTimeHow many seconds someone get banned if he floods
TemplateServeradminGroupTemplateServerdefaultGroupTemplateChanneladminGroupTemplateChannelDefaultGroupPermissionsVersionPendingConnectionsPerIpEndmarkerTrait Implementations
impl Debug for ServerInstancePropertiesRare[src]
impl PartialEq for ServerInstancePropertiesRare[src]
fn eq(&self, __arg_0: &ServerInstancePropertiesRare) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.
impl Eq for ServerInstancePropertiesRare[src]
impl Clone for ServerInstancePropertiesRare[src]
fn clone(&self) -> ServerInstancePropertiesRare
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more